0.9.9 API documentation: normalize_dot.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

normalize_dot.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../gtx/fast_square_root.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_normalize_dot is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_normalize_dot extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
36 template<length_t L, typename T, qualifier Q>
37 GLM_FUNC_DECL T normalizeDot(vec<L, T, Q> const& x, vec<L, T, Q> const& y);
38
43 template<length_t L, typename T, qualifier Q>
44 GLM_FUNC_DECL T fastNormalizeDot(vec<L, T, Q> const& x, vec<L, T, Q> const& y);
45
47 }//namespace glm
48
49 #include "normalize_dot.inl"
glm::normalizeDot
GLM_FUNC_DECL T normalizeDot(vec< L, T, Q > const &x, vec< L, T, Q > const &y)
Normalize parameters and returns the dot product of x and y.
glm::fastNormalizeDot
GLM_FUNC_DECL T fastNormalizeDot(vec< L, T, Q > const &x, vec< L, T, Q > const &y)
Normalize parameters and returns the dot product of x and y.
glm
Definition: common.hpp:20